{ "Helvetica",			  0.700,	0,	0 },
{ "Helvetica-Bold",		  0.709,	0,	0 },
{ "Helvetica-Oblique",		  0.700,	0,	0 },
{ "Helvetica-BoldOblique",	  0.709,	0,	0 },
{ "Times-Roman",		  0.673,	0,	0 },
{ "Times-Bold",			  0.685,	0,	0 },
{ "Times-Italic",		  0.673,	0,	0 },
{ "Times-BoldItalic",		  0.685,	0,	0 },
{ "Courier",			  0.620,	0,	0 },
{ "Courier-Bold",		  0.620,	0,	0 },
{ "Courier-Oblique",		  0.620,	0,	0 },
{ "Courier-BoldOblique",	  0.620,	0,	0 },
{ "Symbol",			  0.679,	1,	1 },
{ "AvantGarde-Book",		  0.734,	0,	0 },
{ "AvantGarde-BookOblique",	  0.734,	0,	0 },
{ "AvantGarde-Demi",		  0.734,	0,	0 },
{ "AvantGarde-DemiOblique",	  0.734,	0,	0 },
{ "Bookman-Demi",		  0.675,	0,	0 },
{ "Bookman-DemiItalic",		  0.675,	0,	0 },
{ "Bookman-Light",		  0.675,	0,	0 },
{ "Bookman-LightItalic",	  0.675,	0,	0 },
{ "Helvetica-Narrow",		  0.700,	0,	0 },
{ "Helvetica-Narrow-Bold",	  0.706,	0,	0 },
{ "Helvetica-Narrow-Oblique",	  0.700,	0,	0 },
{ "Helvetica-Narrow-BoldOblique", 0.706,	0,	0 },
{ "NewCenturySchlbk-Roman",	  0.704,	0,	0 },
{ "NewCenturySchlbk-Italic",	  0.704,	0,	0 },
{ "NewCenturySchlbk-Bold",	  0.704,	0,	0 },
{ "NewCenturySchlbk-BoldItalic",  0.704,	0,	0 },
{ "Palatino-Roman",		  0.689,	0,	0 },
{ "Palatino-Italic",		  0.700,	0,	0 },
{ "Palatino-Bold",		  0.665,	0,	0 },
{ "Palatino-BoldItalic",	  0.677,	0,	0 },
{ "ZapfChancery-MediumItalic",	  0.610,	0,	0 },
{ "ZapfDingbats",		  0.700,	1,	1 },
{ "Ryumin-Light-EUC-H",		  0.700,	1,	1 },
{ "Ryumin-Light-EUC-V",		  0.700,	1,	1 },
{ "GothicBBB-Medium-EUC-H",	  0.700,	1,	1 },
{ "GothicBBB-Medium-EUC-V",	  0.700,	1,	1 },
